@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -28,8 +29,6 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_svtools.hxx"
 
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil -*- */
- 
 #include <stdio.h>		                // for EOF
 #include <rtl/tencinfo.h>
 #include <tools/stream.hxx>
@@ -342,12 +341,6 @@ void SvRTFParser::ScanText( const sal_Unicode cBreak )
                 case '\'':
                     {
 
-#if 0
-                        // #i35653 patch from cmc
-                        ByteString aByteString(static_cast<char>(GetHexValue()));
-                        if (aByteString.Len())
-                            aStrBuffer.Append(String(aByteString, GetSrcEncoding()));
-#else
                         ByteString aByteString;
                         while (1)
                         {
@@ -398,7 +391,6 @@ void SvRTFParser::ScanText( const sal_Unicode cBreak )
 
                         if (aByteString.Len())
                             aStrBuffer.Append(String(aByteString, GetSrcEncoding()));
-#endif
                     }
                     break;
                 case '\\':
@@ -707,4 +699,4 @@ void SvRTFParser::RestoreState()
 }
 #endif
 
-/* vi:set tabstop=4 shiftwidth=4 expandtab: */
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
