@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -78,12 +79,6 @@ GlyphCache::~GlyphCache()
 
 void GlyphCache::InvalidateAllGlyphs()
 {
-#if 0 // TODO: implement uncaching of all glyph shapes and metrics
-    for( FontList::iterator it = maFontList.begin(); it != maFontList.end(); ++it )
-        delete const_cast<ServerFont*>( it->second );
-    maFontList.clear();
-    mpCurrentGCFont = NULL;
-#endif
 }
 
 // -----------------------------------------------------------------------
@@ -594,3 +589,4 @@ int ExtraKernInfo::GetUnscaledKernValue( sal_Unicode cLeft, sal_Unicode cRight )
 
 // =======================================================================
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
