@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -28,16 +29,12 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_vcl.hxx"
 #include <tools/list.hxx>
-#ifndef _TABLE_HXX
 #include <tools/table.hxx>
-#endif
 #include <tools/debug.hxx>
 #include <vcl/svapp.hxx>
 #include <vcl/accel.h>
 #include <vcl/accel.hxx>
-#ifndef _RC_H
 #include <tools/rc.h>
-#endif
 
 
 
@@ -729,3 +726,5 @@ Accelerator& Accelerator::operator=( const Accelerator& rAccel )
 
     return *this;
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
